<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="sr@latin" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation>Ponašanje</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation>Automatski sačuvaj dokumente</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation>Upamti geometriju prozora</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation>Otvaraj spoljne veze u ReText prozoru</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Proširenja sintakse Markdown (odvojeno zapetom)</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation>Uređivač</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation>Istakni trenutnu liniju</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation>Prikaži brojeve linija</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation>Tab ubacuje razmake</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation>Širina tabulacije</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation>Sučelje</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation>Naziv teme ikona</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation>Fajl rasporeda</translation>
    </message>
    <message>
        <location filename="config.py" line="103"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Draw vertical line at column</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation>(ništa)</translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation>Izaberite fajl</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Unesite oznaku lokaliteta (npr. sr_RS)</translation>
    </message>
    <message>
        <location filename="dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Postavi kao podrazumevano</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation>Nema upisa od poslednje izmene (dodajte ! da pregazite)</translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation>Podaci</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Images (*.png *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="177"/>
        <source>New document</source>
        <translation>Novi dokument</translation>
    </message>
    <message>
        <location filename="tab.py" line="182"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Ne mogu da raščlanim sadržaj fajla, Proverite da li imate instaliran &lt;a href=&quot;%s&quot;&gt;neophodan modul&lt;/a&gt;!</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="81"/>
        <source>File toolbar</source>
        <translation>Fajl alatna traka</translation>
    </message>
    <message>
        <location filename="window.py" line="83"/>
        <source>Edit toolbar</source>
        <translation>Uredi alatna traka</translation>
    </message>
    <message>
        <location filename="window.py" line="85"/>
        <source>Search toolbar</source>
        <translation>Alatna traka traženja</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <location filename="window.py" line="92"/>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>Set encoding</source>
        <translation>Postavi kodiranje</translation>
    </message>
    <message>
        <location filename="window.py" line="1044"/>
        <source>Reload</source>
        <translation>Učitaj ponovo</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Save</source>
        <translation>Sačuvaj</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save as</source>
        <translation>Sačuvaj kao</translation>
    </message>
    <message>
        <location filename="window.py" line="107"/>
        <source>Next tab</source>
        <translation>Sledeći jezičak</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Previous tab</source>
        <translation>Prethodni jezičak</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Print</source>
        <translation>Štampaj</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Print preview</source>
        <translation>Prikaz štampe</translation>
    </message>
    <message>
        <location filename="window.py" line="116"/>
        <source>View HTML code</source>
        <translation>Pogledaj HTML kod</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Find text</source>
        <translation>Nađi tekst</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Preview</source>
        <translation>Pregled</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Trenutni pregled</translation>
    </message>
    <message>
        <location filename="window.py" line="140"/>
        <source>Table editing mode</source>
        <translation>Režim tabele</translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>FakeVim mode</source>
        <translation>Lažni Vim režim</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Fullscreen mode</source>
        <translation>Režim punog ekrana</translation>
    </message>
    <message>
        <location filename="window.py" line="553"/>
        <source>Preferences</source>
        <translation>Podešavanja</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>Quit</source>
        <translation>Napusti</translation>
    </message>
    <message>
        <location filename="window.py" line="162"/>
        <source>Undo</source>
        <translation>Poništi</translation>
    </message>
    <message>
        <location filename="window.py" line="164"/>
        <source>Redo</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Cut</source>
        <translation>Iseci</translation>
    </message>
    <message>
        <location filename="window.py" line="170"/>
        <source>Paste</source>
        <translation>Nalepi</translation>
    </message>
    <message>
        <location filename="window.py" line="180"/>
        <source>Enable</source>
        <translation>Uključi</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Set locale</source>
        <translation>Postavi lokalitet</translation>
    </message>
    <message>
        <location filename="window.py" line="182"/>
        <source>Use WebKit renderer</source>
        <translation>Koristi WebKit iscrtavač</translation>
    </message>
    <message>
        <location filename="window.py" line="187"/>
        <source>Show directory</source>
        <translation>Prikaži direktorijum</translation>
    </message>
    <message>
        <location filename="window.py" line="188"/>
        <source>Next</source>
        <translation>Sledeće</translation>
    </message>
    <message>
        <location filename="window.py" line="190"/>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Get help online</source>
        <translation>Potražite pomoć na internetu</translation>
    </message>
    <message>
        <location filename="window.py" line="196"/>
        <source>About ReText</source>
        <translation>O programu ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="199"/>
        <source>About Qt</source>
        <translation>O QT-u</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Bold</source>
        <translation>Podebljano</translation>
    </message>
    <message>
        <location filename="window.py" line="216"/>
        <source>Italic</source>
        <translation>Kurzivno</translation>
    </message>
    <message>
        <location filename="window.py" line="218"/>
        <source>Underline</source>
        <translation>Podvučeno</translation>
    </message>
    <message>
        <location filename="window.py" line="230"/>
        <source>Symbols</source>
        <translation>Simboli</translation>
    </message>
    <message>
        <location filename="window.py" line="235"/>
        <source>File</source>
        <translation>Fajl</translation>
    </message>
    <message>
        <location filename="window.py" line="236"/>
        <source>Edit</source>
        <translation>Uređivanje</translation>
    </message>
    <message>
        <location filename="window.py" line="237"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="window.py" line="240"/>
        <source>Open recent</source>
        <translation>Otvori nedavne</translation>
    </message>
    <message>
        <location filename="window.py" line="252"/>
        <source>Export</source>
        <translation>Izvezi</translation>
    </message>
    <message>
        <location filename="window.py" line="273"/>
        <source>Spell check</source>
        <translation>Provera pravopisa</translation>
    </message>
    <message>
        <location filename="window.py" line="281"/>
        <source>Default markup</source>
        <translation>Podrazumevana markacija</translation>
    </message>
    <message>
        <location filename="window.py" line="284"/>
        <source>Formatting</source>
        <translation>Formatiranje</translation>
    </message>
    <message>
        <location filename="window.py" line="321"/>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
    <message>
        <location filename="window.py" line="323"/>
        <source>Case sensitively</source>
        <translation>Osetljiv na vel. slova</translation>
    </message>
    <message>
        <location filename="window.py" line="458"/>
        <source>New document</source>
        <translation>Novi dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="622"/>
        <source>Please, save the file somewhere.</source>
        <translation>Sačuvajte fajl negde.</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Select one or several files to open</source>
        <translation>Izaberite jedan ili više fajlova za otvaranje</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Supported files</source>
        <translation>Podržani fajlovi</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>All files (*)</source>
        <translation>Svi fajlovi (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="776"/>
        <source>Select file encoding from the list:</source>
        <translation>Sa liste izaberite kodiranje fajla:</translation>
    </message>
    <message>
        <location filename="window.py" line="797"/>
        <source>Plain text (*.txt)</source>
        <translation>Običan tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="800"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s fajlovi</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>Save file</source>
        <translation>Sačuvaj fajl</translation>
    </message>
    <message>
        <location filename="window.py" line="821"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Ne mogu da sačuvam jer je fajl samo za čitanje!</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>Export document to ODT</source>
        <translation>Izvezi dokument u ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument tekstualni fajl (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML fajlovi (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>Export document to PDF</source>
        <translation>Izvezi dokument u PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF fajlovi (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="908"/>
        <source>Print document</source>
        <translation>Štampaj dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="932"/>
        <source>Export document</source>
        <translation>Izvezi dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="953"/>
        <source>Failed to execute the command:</source>
        <translation>Neuspelo izvršenje komande:</translation>
    </message>
    <message>
        <location filename="window.py" line="1028"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Ovaj fajl je obrisala druga aplikacije.
Sačuvajte ga pre nego što izađete.</translation>
    </message>
    <message>
        <location filename="window.py" line="1035"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Ovaj dokument je izmenila druga aplikacija.
Želite li da ga ponovo učitate? (ovo će poništiti sve vaše izmene)</translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Ako izaberete da ne učitate ponovo, automatsko čuvanje biće isključeno za ovu sesiju da bi se sprečio gubitak podataka.</translation>
    </message>
    <message>
        <location filename="window.py" line="1064"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokument je izmenjen.
Želite li da sačuvate vaše izmene?</translation>
    </message>
    <message>
        <location filename="window.py" line="1089"/>
        <source>HTML code</source>
        <translation>HTML kod</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Jednostavan ali moćan uređivač za Markdown i reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitrij Šačnev (Dmitry Shachnev), 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Website</source>
        <translation>Web sajt</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Markdown syntax</source>
        <translation>Sintaksa Markdown</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>reStructuredText syntax</source>
        <translation>Sintaksa reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="117"/>
        <source>Change editor font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="119"/>
        <source>Change preview font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="192"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="987"/>
        <source>Alt text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>Link text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
